import { css } from "@emotion/react";
import styled from "@emotion/styled";
import { motion } from "framer-motion";
import { observer } from "mobx-react-lite";
import React, { useCallback, useEffect, useState } from "react";
import { ErrorState } from "./ErrorState";

export const Error = observer(({ state }: { state: ErrorState }) => {
  const [expanded, setExpanded] = useState(false);
  useEffect(() => {
    if (!state.error?.details) {
      setExpanded(false);
    }
  }, [state.error, setExpanded]);
  const onToggle = useCallback(() => {
    if (!state.error?.details) {
      return;
    }
    setExpanded(!expanded);
  }, [state.error, expanded, setExpanded]);

  if (!state.error) {
    return null;
  }
  return (
    <>
      <ErrorTitle
        animate={{
          y: 0,
        }}
        initial={{
          y: 100,
        }}
        transition={{
          delay: 1,
          type: "tween",
        }}
        $expandable={!!state.error.details}
        onClick={onToggle}
      >
        {state.error.title}
      </ErrorTitle>
      {expanded && <ErrorDetails>{state.error.details}</ErrorDetails>}
    </>
  );
});

const ErrorBase = styled(motion.pre)`
  background: hsl(0, 50%, 80%);
  color: hsl(0, 80%, 20%);
  padding: 8px;
  margin: 0;
`;

const ErrorTitle = styled(ErrorBase)<{ $expandable: boolean }>`
  font-weight: 600;
  ${({ $expandable }) =>
    $expandable &&
    css`
      cursor: pointer;
    `}
`;

const ErrorDetails = styled(ErrorBase)`
  max-height: 400px;
  overflow-x: hidden;
  overflow-y: auto;
`;
