import styled from "@emotion/styled";
import React, { useCallback } from "react";

declare global {
  interface Window {
    // Exposed in IntelliJ plugin.
    openInExternalBrowser?(url: string): void;
  }
}

export const Link = (
  props: React.DetailedHTMLProps<
    React.AnchorHTMLAttributes<HTMLAnchorElement>,
    HTMLAnchorElement
  >
) => {
  const onClick = useCallback(
    (event: React.MouseEvent<HTMLAnchorElement, MouseEvent>) => {
      if (props.href) {
        openUrl(props.href);
        event.preventDefault();
      }
      return props.onClick && props.onClick(event);
    },
    [props]
  );
  // eslint-disable-next-line jsx-a11y/anchor-has-content
  return <StyledA {...props} onClick={onClick} />;
};

export function openUrl(url: string) {
  if (window.openInExternalBrowser) {
    window.openInExternalBrowser(url);
    return;
  }
  if (navigator.userAgent.includes(" Code/")) {
    window.parent.postMessage(
      {
        command: "open-browser",
        url,
      },
      "*"
    );
    return;
  }
  // We must be running in a browser.
  window.open(url, "_blank");
}

const StyledA = styled.a`
  color: hsl(213, 100%, 10%);
`;
